@@ -3,17 +3,18 @@
 //! Convolutions in this library can be defined in time or frequency domain. In
 //! frequency domain the convolution is automatically transformed into a multiplication
 //! which is the analog operation to a convolution in time domain.
-use numbers::*;
-use std::ops::*;
-use num_complex::{Complex32, Complex64};
-use std::marker::PhantomData;
-use vector_types::*;
-use inline_vector::InlineVector;
 use super::FixedLenBuffer;
+use inline_vector::InlineVector;
+use num_complex::{Complex32, Complex64};
+use numbers::*;
+use std::marker::PhantomData;
+use std::ops::*;
+use vector_types::*;
 
 /// A convolution function in time domain and real number space
 pub trait RealImpulseResponse<T>: Sync
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     /// Indicates whether this function is symmetric around 0 or not.
     /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
@@ -25,7 +26,8 @@ pub trait RealImpulseResponse<T>: Sync
 
 /// A convolution function in frequency domain and real number space
 pub trait RealFrequencyResponse<T>: Sync
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     /// Indicates whether this function is symmetric around 0 or not.
     /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
@@ -37,7 +39,8 @@ pub trait RealFrequencyResponse<T>: Sync
 
 /// A convolution function in time domain and complex number space
 pub trait ComplexImpulseResponse<T>: Sync
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     /// Indicates whether this function is symmetric around 0 or not.
     /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
@@ -49,7 +52,8 @@ pub trait ComplexImpulseResponse<T>: Sync
 
 /// A convolution function in frequency domain and complex number space
 pub trait ComplexFrequencyResponse<T>: Sync
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     /// Indicates whether this function is symmetric around 0 or not.
     /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
@@ -120,8 +124,10 @@ macro_rules! define_complex_lookup_table {
 define_complex_lookup_table!(ComplexTimeLinearTableLookup; ComplexFrequencyLinearTableLookup);
 
 /// Linear interpolation between two points.
-fn linear_interpolation_between_bins<T: RealNumber, C>(x: T, round: usize, table: &[C]) -> C 
-    where C: Mul<C, Output = C> + Add<C, Output = C> + Sub<C, Output = C> + Mul<T, Output = C> + Copy {
+fn linear_interpolation_between_bins<T: RealNumber, C>(x: T, round: usize, table: &[C]) -> C
+where
+    C: Mul<C, Output = C> + Add<C, Output = C> + Sub<C, Output = C> + Mul<T, Output = C> + Copy,
+{
     let round_float = T::from(round).unwrap();
     let len = table.len();
     if x > round_float {
@@ -252,7 +258,9 @@ macro_rules! add_complex_linear_table_impl {
             $(
                 impl $name<$data_type> {
                     /// Convert the lookup table into real number space
+                    #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
                     pub fn to_real(self) -> $real<$data_type> {
+                        // TODO 0.6: rename method name to fix clippy warning
                         let complex = &self.table[..];
                         let mut interleaved = InlineVector::with_capacity(2 * complex.len());
                         for n in complex {
@@ -347,7 +355,6 @@ macro_rules! add_real_time_linear_table_impl {
 }
 add_real_time_linear_table_impl!(f32, f64);
 
-
 macro_rules! add_complex_frequency_linear_table_impl {
     ($($data_type: ident),*) => {
         $(
@@ -384,13 +391,15 @@ add_complex_frequency_linear_table_impl!(f32, f64);
 
 /// Raised cosine function according to `https://en.wikipedia.org/wiki/Raised-cosine_filter`
 pub struct RaisedCosineFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     rolloff: T,
 }
 
 impl<T> RealImpulseResponse<T> for RaisedCosineFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     fn is_symmetric(&self) -> bool {
         true
@@ -417,7 +426,8 @@ impl<T> RealImpulseResponse<T> for RaisedCosineFunction<T>
 }
 
 impl<T> RealFrequencyResponse<T> for RaisedCosineFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     fn is_symmetric(&self) -> bool {
         true
@@ -433,8 +443,8 @@ impl<T> RealFrequencyResponse<T> for RaisedCosineFunction<T>
         }
 
         if ((one - self.rolloff) < x.abs()) && (x.abs() <= (one + self.rolloff)) {
-            return one / two *
-                   (one + (pi / self.rolloff * (x.abs() - (one - self.rolloff)) / two).cos());
+            return one / two
+                * (one + (pi / self.rolloff * (x.abs() - (one - self.rolloff)) / two).cos());
         }
 
         T::zero()
@@ -442,23 +452,27 @@ impl<T> RealFrequencyResponse<T> for RaisedCosineFunction<T>
 }
 
 impl<T> RaisedCosineFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     /// Creates a raised cosine function.
     pub fn new(rolloff: T) -> Self {
-        RaisedCosineFunction { rolloff: rolloff }
+        RaisedCosineFunction { rolloff }
     }
 }
 
 /// Sinc function according to `https://en.wikipedia.org/wiki/Sinc_function`
+#[derive(Default)]
 pub struct SincFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     _ghost: PhantomData<T>,
 }
 
 impl<T> RealImpulseResponse<T> for SincFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     fn is_symmetric(&self) -> bool {
         true
@@ -476,7 +490,8 @@ impl<T> RealImpulseResponse<T> for SincFunction<T>
 }
 
 impl<T> RealFrequencyResponse<T> for SincFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     fn is_symmetric(&self) -> bool {
         true
@@ -493,11 +508,14 @@ impl<T> RealFrequencyResponse<T> for SincFunction<T>
 }
 
 impl<T> SincFunction<T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     /// Creates a sinc function.
     pub fn new() -> Self {
-        SincFunction { _ghost: PhantomData }
+        SincFunction {
+            _ghost: PhantomData,
+        }
     }
 }
 
@@ -507,8 +525,9 @@ mod tests {
     use std::fmt::Debug;
 
     fn conv_test<T, C>(conv: C, expected: &[T], step: T, tolerance: T)
-        where T: RealNumber + Debug,
-              C: RealImpulseResponse<T>
+    where
+        T: RealNumber + Debug,
+        C: RealImpulseResponse<T>,
     {
         let mut result = vec![T::zero(); expected.len()];
         let mut j = -(expected.len() as isize / 2);
@@ -525,8 +544,9 @@ mod tests {
     }
 
     fn complex_conv_test<T, C>(conv: C, expected: &[T], step: T, tolerance: T)
-        where T: RealNumber + Debug,
-              C: ComplexImpulseResponse<T>
+    where
+        T: RealNumber + Debug,
+        C: ComplexImpulseResponse<T>,
     {
         let mut result = vec![Complex::<T>::zero(); expected.len()];
         let mut j = -(expected.len() as isize / 2);
@@ -543,8 +563,9 @@ mod tests {
     }
 
     fn real_freq_conv_test<T, C>(conv: C, expected: &[T], step: T, tolerance: T)
-        where T: RealNumber + Debug,
-              C: RealFrequencyResponse<T>
+    where
+        T: RealNumber + Debug,
+        C: RealFrequencyResponse<T>,
     {
         let mut result = vec![T::zero(); expected.len()];
         let mut j = -(expected.len() as isize / 2);
@@ -563,24 +584,27 @@ mod tests {
     #[test]
     fn raised_cosine_test() {
         let rc = RaisedCosineFunction::new(0.35);
-        let expected = [0.0,
-                        0.2171850639713355,
-                        0.4840621929215732,
-                        0.7430526238101408,
-                        0.9312114164253432,
-                        1.0,
-                        0.9312114164253432,
-                        0.7430526238101408,
-                        0.4840621929215732,
-                        0.2171850639713355];
+        let expected = [
+            0.0,
+            0.2171850639713355,
+            0.4840621929215732,
+            0.7430526238101408,
+            0.9312114164253432,
+            1.0,
+            0.9312114164253432,
+            0.7430526238101408,
+            0.4840621929215732,
+            0.2171850639713355,
+        ];
         conv_test(rc, &expected, 0.2, 1e-4);
     }
 
     #[test]
     fn sinc_test() {
         let rc = SincFunction::<f32>::new();
-        let expected = [0.1273, -0.0000, -0.2122, 0.0000, 0.6366, 1.0000, 0.6366, 0.0000, -0.2122,
-                        -0.0000];
+        let expected = [
+            0.1273, -0.0000, -0.2122, 0.0000, 0.6366, 1.0000, 0.6366, 0.0000, -0.2122, -0.0000,
+        ];
         conv_test(rc, &expected, 0.5, 1e-4);
     }
 
@@ -595,16 +619,18 @@ mod tests {
     fn lookup_table_test() {
         let rc = RaisedCosineFunction::new(0.35);
         let table = RealTimeLinearTableLookup::<f64>::from_conv_function(&rc, 0.2, 5);
-        let expected = [0.0,
-                        0.2171850639713355,
-                        0.4840621929215732,
-                        0.7430526238101408,
-                        0.9312114164253432,
-                        1.0,
-                        0.9312114164253432,
-                        0.7430526238101408,
-                        0.4840621929215732,
-                        0.2171850639713355];
+        let expected = [
+            0.0,
+            0.2171850639713355,
+            0.4840621929215732,
+            0.7430526238101408,
+            0.9312114164253432,
+            1.0,
+            0.9312114164253432,
+            0.7430526238101408,
+            0.4840621929215732,
+            0.2171850639713355,
+        ];
         conv_test(table, &expected, 0.2, 1e-4);
     }
 
@@ -612,16 +638,18 @@ mod tests {
     fn linear_interpolation_lookup_table_test() {
         let rc = RaisedCosineFunction::new(0.35);
         let table = RealTimeLinearTableLookup::<f64>::from_conv_function(&rc, 0.4, 5);
-        let expected = [0.0,
-                        0.2171850639713355,
-                        0.4840621929215732,
-                        0.7430526238101408,
-                        0.9312114164253432,
-                        1.0,
-                        0.9312114164253432,
-                        0.7430526238101408,
-                        0.4840621929215732,
-                        0.2171850639713355];
+        let expected = [
+            0.0,
+            0.2171850639713355,
+            0.4840621929215732,
+            0.7430526238101408,
+            0.9312114164253432,
+            1.0,
+            0.9312114164253432,
+            0.7430526238101408,
+            0.4840621929215732,
+            0.2171850639713355,
+        ];
         conv_test(table, &expected, 0.2, 0.1);
     }
 
@@ -630,16 +658,18 @@ mod tests {
         let rc = RaisedCosineFunction::new(0.35);
         let table = RealTimeLinearTableLookup::<f64>::from_conv_function(&rc, 0.4, 5);
         let complex = table.to_complex();
-        let expected = [0.0,
-                        0.2171850639713355,
-                        0.4840621929215732,
-                        0.7430526238101408,
-                        0.9312114164253432,
-                        1.0,
-                        0.9312114164253432,
-                        0.7430526238101408,
-                        0.4840621929215732,
-                        0.2171850639713355];
+        let expected = [
+            0.0,
+            0.2171850639713355,
+            0.4840621929215732,
+            0.7430526238101408,
+            0.9312114164253432,
+            1.0,
+            0.9312114164253432,
+            0.7430526238101408,
+            0.4840621929215732,
+            0.2171850639713355,
+        ];
         complex_conv_test(complex, &expected, 0.2, 0.1);
     }
 
@@ -649,24 +679,27 @@ mod tests {
         let table = RealTimeLinearTableLookup::<f64>::from_conv_function(&rc, 0.2, 5);
         let freq = table.fft();
         assert_eq!(freq.delta(), 2.2);
-        let expected = [0.0078, 0.0269, 0.0602, 0.1311, 2.7701, 5.6396, 2.7701, 0.1311, 0.0602,
-                        0.0269, 0.0078];
+        let expected = [
+            0.0078, 0.0269, 0.0602, 0.1311, 2.7701, 5.6396, 2.7701, 0.1311, 0.0602, 0.0269, 0.0078,
+        ];
         real_freq_conv_test(freq, &expected, 2.2, 0.1);
     }
 
     #[test]
     fn freq_test() {
         let rc = RaisedCosineFunction::new(0.5);
-        let expected = [0.0,
-                        0.0,
-                        0.20610737385376332,
-                        0.7938926261462365,
-                        1.0,
-                        1.0,
-                        1.0,
-                        0.7938926261462365,
-                        0.20610737385376332,
-                        0.0];
+        let expected = [
+            0.0,
+            0.0,
+            0.20610737385376332,
+            0.7938926261462365,
+            1.0,
+            1.0,
+            1.0,
+            0.7938926261462365,
+            0.20610737385376332,
+            0.0,
+        ];
         real_freq_conv_test(rc, &expected, 0.4, 0.1);
     }
 }
