@@ -1,13 +1,13 @@
-#[cfg(any(feature = "doc", feature="use_gpu"))]
+#[cfg(any(feature = "doc", feature = "use_gpu"))]
 mod ocl;
 
-#[cfg(any(feature = "doc", feature="use_gpu"))]
+#[cfg(any(feature = "doc", feature = "use_gpu"))]
 pub use self::ocl::*;
 
-#[cfg(any(feature = "doc", not(feature="use_gpu")))]
+#[cfg(any(feature = "doc", not(feature = "use_gpu")))]
 mod fallback;
 
-#[cfg(any(feature = "doc", not(feature="use_gpu")))]
+#[cfg(any(feature = "doc", not(feature = "use_gpu")))]
 pub use self::fallback::*;
 
 use numbers::*;
@@ -20,11 +20,12 @@ pub trait GpuSupport<T: RealNumber> {
     fn has_gpu_support() -> bool;
 
     /// Convolve a vector on the GPU.
-    fn gpu_convolve_vector(is_complex: bool,
-                           source: &[T],
-                           target: &mut [T],
-                           imp_resp: &[T])
-                           -> Option<Range<usize>>;
+    fn gpu_convolve_vector(
+        is_complex: bool,
+        source: &[T],
+        target: &mut [T],
+        imp_resp: &[T],
+    ) -> Option<Range<usize>>;
 
     /// Indicates whether or not the parameters are supported by the FFT implementation.
     fn is_supported_fft_len(is_complex: bool, len: usize) -> bool;
@@ -33,11 +34,12 @@ pub trait GpuSupport<T: RealNumber> {
     fn fft(is_complex: bool, source: &[T], target: &mut [T], reverse: bool);
 
     /// Applys a frequence response to a time domain signal.
-    fn overlap_discard(x_time: &mut [T],
-                       tmp: &mut [T],
-                       x_freq: &mut [T],
-                       h_freq: &[T],
-                       imp_len: usize,
-                       step_size: usize)
-                       -> usize;
+    fn overlap_discard(
+        x_time: &mut [T],
+        tmp: &mut [T],
+        x_freq: &mut [T],
+        h_freq: &[T],
+        imp_len: usize,
+        step_size: usize,
+    ) -> usize;
 }
