@@ -39,7 +39,7 @@
 //!
 //! The vector types don't distinguish between the shapes 1xN or Nx1. This is a difference to other
 //! conventions such as in MATLAB or GNU Octave.
-//! The reason for this decision is that most operations are only defined if the shape of the 
+//! The reason for this decision is that most operations are only defined if the shape of the
 //! vector matches. So it appears to be more practical and clearer to implement the few operations
 //! where the arguments can be of different shapes as seperate methods. The methods `mul` and `dot_product`
 //! are one example for this.
@@ -48,73 +48,109 @@
 //! There is a wide range of DSP vectors, e.g. a slice can be DSP vector, a boxed array can be a DSP vector,
 //! a standard vector can be a DSP vector and so on. This lib tries to work with all of that and tries
 //! to allow all those different DSP vector types to work together. The price for this flexibility is a more complex
-//! trait definition. As a mental model, this is what the traits are specifiying: 
+//! trait definition. As a mental model, this is what the traits are specifiying:
 //! Whenever you have a complex vector in time domain, it's binary operations will work with all other
-//! complex vectors in time domain, but not with real valued vectors or frequency domain vectors. 
+//! complex vectors in time domain, but not with real valued vectors or frequency domain vectors.
 //! And the type `GenDspVec` serves as wild card at compile time since it defers all checks to run time.
 
-#[cfg(any(feature = "doc", feature="use_sse", feature="use_avx"))]
-extern crate simd;
-#[cfg(any(feature = "doc", feature="use_gpu"))]
-extern crate ocl;
-#[cfg(feature="std")]
-extern crate num_cpus;
-#[cfg(feature="std")]
-extern crate crossbeam;
-extern crate num_traits;
-extern crate num_complex;
-extern crate rustfft;
-#[cfg(any(feature = "doc", feature="use_gpu"))]
-extern crate clfft;
+#![cfg_attr(feature = "cargo-clippy", feature(tool_lints))]
+#![cfg_attr(
+    feature = "cargo-clippy",
+    allow(clippy::new_without_default_derive)
+)] // This LINT gives false positives
+
 extern crate arrayvec;
+#[cfg(any(feature = "doc", feature = "use_gpu"))]
+extern crate clfft;
+#[cfg(feature = "std")]
+extern crate crossbeam;
+#[cfg(feature = "std")]
+#[macro_use]
+extern crate lazy_static;
+#[cfg(feature = "std")]
+extern crate linreg;
+extern crate num_complex;
+#[cfg(feature = "std")]
+extern crate num_cpus;
+extern crate num_traits;
+#[cfg(any(feature = "doc", feature = "use_gpu"))]
+extern crate ocl;
+extern crate rustfft;
+#[cfg(any(feature = "doc", feature = "use_sse", feature = "use_avx"))]
+extern crate simd;
+#[cfg(feature = "std")]
+extern crate time;
 #[macro_use]
 mod simd_extensions;
-mod vector_types;
-mod multicore_support;
-pub mod window_functions;
 pub mod conv_types;
-pub use vector_types::*;
+mod multicore_support;
+mod vector_types;
+pub mod window_functions;
+pub use multicore_support::print_calibration;
 pub use multicore_support::MultiCoreSettings;
+pub use vector_types::*;
 mod gpu_support;
-use std::mem;
 mod inline_vector;
 use numbers::*;
 use std::ops::Range;
 
 pub mod numbers {
     //! Traits from the `num` crate which are used inside `basic_dsp` and extensions to those traits.
-    pub use num_traits::Float;
-    pub use num_traits::One;
+    use gpu_support::{Gpu32, Gpu64, GpuFloat, GpuRegTrait};
     pub use num_complex::Complex;
-    pub use num_traits::Num;
-    use std::fmt::Debug;
-    use rustfft;
     use num_traits;
+    pub use num_traits::Float;
+    pub use num_traits::Num;
+    pub use num_traits::One;
+    use rustfft;
+    #[cfg(any(
+        feature = "use_sse",
+        feature = "use_avx",
+        feature = "use_avx512"
+    ))]
+    use simd;
     use simd_extensions;
     use simd_extensions::*;
-    use gpu_support::{Gpu32, Gpu64, GpuRegTrait, GpuFloat};
-    #[cfg(any(feature="use_sse", feature="use_avx", feature="use_avx512"))]
-    use simd;
+    use std::fmt::Debug;
 
     /// A trait for a numeric value which at least supports a subset of the operations defined in this crate.
     /// Can be an integer or a floating point number. In order to have support for all operations in this crate
     /// a must implement the `RealNumber`.
-    pub trait DspNumber
-        : Num + Copy + Clone + Send + Sync + ToSimd + Debug + num_traits::Signed + num_traits::FromPrimitive + rustfft::FFTnum + 'static
+    pub trait DspNumber:
+        Num
+        + Copy
+        + Clone
+        + Send
+        + Sync
+        + ToSimd
+        + Debug
+        + num_traits::Signed
+        + num_traits::FromPrimitive
+        + rustfft::FFTnum
+        + 'static
     {
-    }
-    impl<T> DspNumber for T
-        where T: Num + Copy + Clone + Send + Sync + ToSimd + Debug + num_traits::Signed + num_traits::FromPrimitive + rustfft::FFTnum + 'static
-    {
-    }
+}
+    impl<T> DspNumber for T where
+        T: Num
+            + Copy
+            + Clone
+            + Send
+            + Sync
+            + ToSimd
+            + Debug
+            + num_traits::Signed
+            + num_traits::FromPrimitive
+            + rustfft::FFTnum
+            + 'static
+    {}
 
     /// Associates a number type with a SIMD register type.
     pub trait ToSimd: Sized + Sync + Send {
         /// Type for the SIMD register on the CPU.
         type RegFallback: SimdGeneric<Self>;
-        type RegSse : SimdGeneric<Self>;
-        type RegAvx : SimdGeneric<Self>;
-        type RegAvx512 : SimdGeneric<Self>;
+        type RegSse: SimdGeneric<Self>;
+        type RegAvx: SimdGeneric<Self>;
+        type RegAvx512: SimdGeneric<Self>;
         /// Type for the SIMD register on the GPU. Defaults to an arbitrary type if GPU support is not
         /// compiled in.
         type GpuReg: GpuRegTrait;
@@ -122,43 +158,43 @@ pub mod numbers {
 
     impl ToSimd for f32 {
         type RegFallback = simd_extensions::fallback::f32x4;
-        
-        #[cfg(feature="use_sse")]
+
+        #[cfg(feature = "use_sse")]
         type RegSse = simd::f32x4;
-        #[cfg(not(feature="use_sse"))]
+        #[cfg(not(feature = "use_sse"))]
         type RegSse = simd_extensions::fallback::f32x4;
-        
-        #[cfg(feature="use_avx")]
+
+        #[cfg(feature = "use_avx")]
         type RegAvx = simd::x86::avx::f32x8;
-        #[cfg(not(feature="use_avx"))]
+        #[cfg(not(feature = "use_avx"))]
         type RegAvx = simd_extensions::fallback::f32x4;
-        
-        #[cfg(feature="use_avx512")]
+
+        #[cfg(feature = "use_avx512")]
         type RegAvx512 = stdsimd::simd::f32x16; // Type is missing in SIMD
-        #[cfg(not(feature="use_avx512"))]
+        #[cfg(not(feature = "use_avx512"))]
         type RegAvx512 = simd_extensions::fallback::f32x4;
-        
+
         type GpuReg = Gpu32;
     }
 
     impl ToSimd for f64 {
         type RegFallback = simd_extensions::fallback::f64x2;
-        
-        #[cfg(feature="use_sse")]
+
+        #[cfg(feature = "use_sse")]
         type RegSse = simd::x86::sse2::f64x2;
-        #[cfg(not(feature="use_sse"))]
+        #[cfg(not(feature = "use_sse"))]
         type RegSse = simd_extensions::fallback::f64x2;
-        
-        #[cfg(feature="use_avx")]
+
+        #[cfg(feature = "use_avx")]
         type RegAvx = simd::x86::avx::f64x4;
-        #[cfg(not(feature="use_avx"))]
+        #[cfg(not(feature = "use_avx"))]
         type RegAvx = simd_extensions::fallback::f64x2;
-        
-        #[cfg(feature="use_avx512")]
+
+        #[cfg(feature = "use_avx512")]
         type RegAvx512 = stdsimd::simd::f64x8; // Type is missing in SIMD
-        #[cfg(not(feature="use_avx512"))]
+        #[cfg(not(feature = "use_avx512"))]
         type RegAvx512 = simd_extensions::fallback::f64x2;
-        
+
         type GpuReg = Gpu64;
     }
 
@@ -173,7 +209,8 @@ pub mod numbers {
     }
 
     impl<T> Zero for T
-        where T: DspNumber
+    where
+        T: DspNumber,
     {
         fn zero() -> Self {
             <Self as num_traits::Zero>::zero()
@@ -181,7 +218,8 @@ pub mod numbers {
     }
 
     impl<T> Zero for Complex<T>
-        where T: DspNumber
+    where
+        T: DspNumber,
     {
         fn zero() -> Self {
             <Self as num_traits::Zero>::zero()
@@ -189,28 +227,49 @@ pub mod numbers {
     }
 }
 
-// Returns a complex slice from a real slice
-fn array_to_complex<T>(array: &[T]) -> &[Complex<T>] {
+/// Transmutes a slice. Both S and D must be `#[repr(C)]`.
+/// The code panics if the slice has a length which doesn't allow conversion.
+fn transmute_slice<S, D>(source: &[S]) -> &[D] {
+    let len = get_target_slice_len::<S, D>(source);
     unsafe {
-        let len = array.len();
-        if len % 2 != 0 {
-            panic!("Argument must have an even length");
-        }
-        let trans: &[Complex<T>] = mem::transmute(array);
-        &trans[0..len / 2]
+        let trans: &[D] = &*(source as *const [S] as *const [D]);
+        std::slice::from_raw_parts(trans.as_ptr(), len)
+    }
+}
+
+/// Transmutes a mutable slice. Both S and D must be `#[repr(C)]`.
+/// The code panics if the slice has a length which doesn't allow conversion.
+fn transmute_slice_mut<S, D>(source: &mut [S]) -> &mut [D] {
+    let len = get_target_slice_len::<S, D>(source);
+    unsafe {
+        let trans: &mut [D] = &mut *(source as *mut [S] as *mut [D]);
+        std::slice::from_raw_parts_mut(trans.as_mut_ptr(), len)
+    }
+}
+
+/// Helper method which finds the length of a target slice and also perform checks on the length
+fn get_target_slice_len<S, D>(source: &[S]) -> usize {
+    let to_larger_type = std::mem::size_of::<D>() >= std::mem::size_of::<S>();
+    if to_larger_type {
+        assert_eq!(std::mem::size_of::<D>() % std::mem::size_of::<S>(), 0);
+        let ratio = std::mem::size_of::<D>() / std::mem::size_of::<S>();
+        assert_eq!(source.len() % ratio, 0);
+        source.len() / ratio
+    } else {
+        assert_eq!(std::mem::size_of::<S>() % std::mem::size_of::<D>(), 0);
+        let ratio = std::mem::size_of::<S>() / std::mem::size_of::<D>();
+        source.len() * ratio
     }
 }
 
+// Returns a complex slice from a real slice
+fn array_to_complex<T>(array: &[T]) -> &[Complex<T>] {
+    transmute_slice(array)
+}
+
 // Returns a complex slice from a real slice
 fn array_to_complex_mut<T>(array: &mut [T]) -> &mut [Complex<T>] {
-    unsafe {
-        let len = array.len();
-        if len % 2 != 0 {
-            panic!("Argument must have an even length");
-        }
-        let trans: &mut [Complex<T>] = mem::transmute(array);
-        &mut trans[0..len / 2]
-    }
+    transmute_slice_mut(array)
 }
 
 /// Copies memory inside a slice
@@ -221,9 +280,7 @@ fn memcpy<T: Copy>(data: &mut [T], from: Range<usize>, to: usize) {
     assert!(to <= data.len() - (from.end - from.start));
     unsafe {
         let ptr = data.as_mut_ptr();
-        copy(ptr.offset(from.start as isize),
-             ptr.offset(to as isize),
-             from.end - from.start)
+        copy(ptr.add(from.start), ptr.add(to), from.end - from.start)
     }
 }
 
@@ -234,7 +291,7 @@ fn memzero<T: Copy>(data: &mut [T], range: Range<usize>) {
     assert!(range.end <= data.len());
     unsafe {
         let ptr = data.as_mut_ptr();
-        write_bytes(ptr.offset(range.start as isize), 0, range.end - range.start);
+        write_bytes(ptr.add(range.start), 0, range.end - range.start);
     }
 }
 
