@@ -1,16 +1,13 @@
-use numbers::*;
 use super::{Simd, SimdFrom};
+use numbers::*;
 use simd::x86::avx::*;
 use std::arch::x86_64::*;
 use std::mem;
 
 /// This value must be read in groups of 2 bits.
-const SWAP_IQ_PS: i32 = 0b10110001;
+const SWAP_IQ_PS: i32 = 0b1011_0001;
 
-/// This value must be read in groups of 2 bits:
-/// 10 means that the third position (since it's the third bit pair)
-/// will be replaced with the value of the second position (10b = 2d)
-const SWAP_IQ_PD: i32 = 0b10110001;
+const SWAP_IQ_PD: i32 = 0b0101;
 
 impl Simd<f32> for f32x8 {
     type Array = [f32; 8];
@@ -23,7 +20,7 @@ impl Simd<f32> for f32x8 {
     }
 
     type ComplexArray = [Complex<f32>; 4];
-    
+
     const LEN: usize = 8;
 
     #[inline]
@@ -37,14 +34,9 @@ impl Simd<f32> for f32x8 {
 
     #[inline]
     fn from_complex(value: Complex<f32>) -> f32x8 {
-        f32x8::new(value.re,
-                   value.im,
-                   value.re,
-                   value.im,
-                   value.re,
-                   value.im,
-                   value.re,
-                   value.im)
+        f32x8::new(
+            value.re, value.im, value.re, value.im, value.re, value.im, value.re, value.im,
+        )
     }
 
     #[inline]
@@ -72,55 +64,78 @@ impl Simd<f32> for f32x8 {
         let parallel = scaling_real * self;
         let shuffled = self.swap_iq();
         let cross = scaling_imag * shuffled;
-        unsafe { mem::transmute(_mm256_addsub_ps(mem::transmute(parallel), mem::transmute(cross))) }
+        unsafe {
+            mem::transmute(_mm256_addsub_ps(
+                mem::transmute(parallel),
+                mem::transmute(cross),
+            ))
+        }
     }
 
     #[inline]
     fn mul_complex(self, value: f32x8) -> f32x8 {
-        let scaling_real = f32x8::new(value.extract(0),
-                                      value.extract(0),
-                                      value.extract(2),
-                                      value.extract(2),
-                                      value.extract(4),
-                                      value.extract(4),
-                                      value.extract(6),
-                                      value.extract(6));
-        let scaling_imag = f32x8::new(value.extract(1),
-                                      value.extract(1),
-                                      value.extract(3),
-                                      value.extract(3),
-                                      value.extract(5),
-                                      value.extract(5),
-                                      value.extract(7),
-                                      value.extract(7));
+        let scaling_real = f32x8::new(
+            value.extract(0),
+            value.extract(0),
+            value.extract(2),
+            value.extract(2),
+            value.extract(4),
+            value.extract(4),
+            value.extract(6),
+            value.extract(6),
+        );
+        let scaling_imag = f32x8::new(
+            value.extract(1),
+            value.extract(1),
+            value.extract(3),
+            value.extract(3),
+            value.extract(5),
+            value.extract(5),
+            value.extract(7),
+            value.extract(7),
+        );
         let parallel = scaling_real * self;
         let shuffled = self.swap_iq();
         let cross = scaling_imag * shuffled;
-        unsafe { mem::transmute(_mm256_addsub_ps(mem::transmute(parallel), mem::transmute(cross))) }
+        unsafe {
+            mem::transmute(_mm256_addsub_ps(
+                mem::transmute(parallel),
+                mem::transmute(cross),
+            ))
+        }
     }
 
     #[inline]
     fn div_complex(self, value: f32x8) -> f32x8 {
-        let scaling_imag = f32x8::new(self.extract(0),
-                                      self.extract(0),
-                                      self.extract(2),
-                                      self.extract(2),
-                                      self.extract(4),
-                                      self.extract(4),
-                                      self.extract(6),
-                                      self.extract(6));
-        let scaling_real = f32x8::new(self.extract(1),
-                                      self.extract(1),
-                                      self.extract(3),
-                                      self.extract(3),
-                                      self.extract(5),
-                                      self.extract(5),
-                                      self.extract(7),
-                                      self.extract(7));
+        let scaling_imag = f32x8::new(
+            self.extract(0),
+            self.extract(0),
+            self.extract(2),
+            self.extract(2),
+            self.extract(4),
+            self.extract(4),
+            self.extract(6),
+            self.extract(6),
+        );
+        let scaling_real = f32x8::new(
+            self.extract(1),
+            self.extract(1),
+            self.extract(3),
+            self.extract(3),
+            self.extract(5),
+            self.extract(5),
+            self.extract(7),
+            self.extract(7),
+        );
         let parallel = scaling_real * value;
         let shuffled = value.swap_iq();
         let cross = scaling_imag * shuffled;
-        let mul: f32x8 = unsafe { mem::transmute(_mm256_addsub_ps(mem::transmute(parallel), mem::transmute(cross))) };
+        let mul: f32x8 = unsafe {
+            mem::transmute(_mm256_addsub_ps(
+                mem::transmute(parallel),
+                mem::transmute(cross),
+            ))
+        };
         let square = shuffled * shuffled;
         let square_shuffled = square.swap_iq();
         let sum = square + square_shuffled;
@@ -131,7 +146,12 @@ impl Simd<f32> for f32x8 {
     #[inline]
     fn complex_abs_squared(self) -> f32x8 {
         let squared = self * self;
-        unsafe { mem::transmute(_mm256_hadd_ps(mem::transmute(squared), mem::transmute(squared))) }
+        unsafe {
+            mem::transmute(_mm256_hadd_ps(
+                mem::transmute(squared),
+                mem::transmute(squared),
+            ))
+        }
     }
 
     #[inline]
@@ -142,12 +162,32 @@ impl Simd<f32> for f32x8 {
 
     #[inline]
     fn complex_abs_squared2(self) -> f32x8 {
-        self.complex_abs_squared()
+        let abs = self.complex_abs_squared();
+        f32x8::new(
+            abs.extract(0),
+            abs.extract(2),
+            abs.extract(1),
+            abs.extract(3),
+            abs.extract(4),
+            abs.extract(6),
+            abs.extract(5),
+            abs.extract(7),
+        )
     }
 
     #[inline]
     fn complex_abs2(self) -> f32x8 {
-        self.complex_abs()
+        let abs = self.complex_abs();
+        f32x8::new(
+            abs.extract(0),
+            abs.extract(2),
+            abs.extract(1),
+            abs.extract(3),
+            abs.extract(4),
+            abs.extract(6),
+            abs.extract(5),
+            abs.extract(7),
+        )
     }
 
     #[inline]
@@ -160,33 +200,41 @@ impl Simd<f32> for f32x8 {
         unsafe {
             *target.get_unchecked_mut(index) = self.extract(0);
             *target.get_unchecked_mut(index + 1) = self.extract(1);
-            *target.get_unchecked_mut(index + 2) = self.extract(2);
-            *target.get_unchecked_mut(index + 3) = self.extract(3);
+            *target.get_unchecked_mut(index + 2) = self.extract(4);
+            *target.get_unchecked_mut(index + 3) = self.extract(5);
         }
     }
 
     #[inline]
     fn sum_real(&self) -> f32 {
-        self.extract(0) + self.extract(1) + self.extract(2) + self.extract(3) +
-        self.extract(4) + self.extract(5) + self.extract(6) + self.extract(7)
+        self.extract(0)
+            + self.extract(1)
+            + self.extract(2)
+            + self.extract(3)
+            + self.extract(4)
+            + self.extract(5)
+            + self.extract(6)
+            + self.extract(7)
     }
 
     #[inline]
     fn sum_complex(&self) -> Complex<f32> {
-        Complex::<f32>::new(self.extract(0) + self.extract(2) + self.extract(4) + self.extract(6),
-                            self.extract(1) + self.extract(3) + self.extract(5) + self.extract(7))
+        Complex::<f32>::new(
+            self.extract(0) + self.extract(2) + self.extract(4) + self.extract(6),
+            self.extract(1) + self.extract(3) + self.extract(5) + self.extract(7),
+        )
     }
-    
+
     #[inline]
     fn max(self, other: Self) -> Self {
         simd::x86::avx::AvxF32x8::max(self, other)
     }
-    
+
     #[inline]
     fn min(self, other: Self) -> Self {
         simd::x86::avx::AvxF32x8::min(self, other)
     }
-    
+
     #[inline]
     fn swap_iq(self) -> Self {
         unsafe { mem::transmute(_mm256_permute_ps(mem::transmute(self), SWAP_IQ_PS)) }
@@ -204,7 +252,7 @@ impl Simd<f64> for f64x4 {
     }
 
     type ComplexArray = [Complex<f64>; 2];
-    
+
     const LEN: usize = 4;
 
     #[inline]
@@ -246,39 +294,62 @@ impl Simd<f64> for f64x4 {
         let parallel = scaling_real * self;
         let shuffled = self.swap_iq();
         let cross = scaling_imag * shuffled;
-        unsafe { mem::transmute(_mm256_addsub_pd(mem::transmute(parallel), mem::transmute(cross))) }
+        unsafe {
+            mem::transmute(_mm256_addsub_pd(
+                mem::transmute(parallel),
+                mem::transmute(cross),
+            ))
+        }
     }
 
     #[inline]
     fn mul_complex(self, value: f64x4) -> f64x4 {
-        let scaling_real = f64x4::new(value.extract(0),
-                                      value.extract(0),
-                                      value.extract(2),
-                                      value.extract(2));
-        let scaling_imag = f64x4::new(value.extract(1),
-                                      value.extract(1),
-                                      value.extract(3),
-                                      value.extract(3));
+        let scaling_real = f64x4::new(
+            value.extract(0),
+            value.extract(0),
+            value.extract(2),
+            value.extract(2),
+        );
+        let scaling_imag = f64x4::new(
+            value.extract(1),
+            value.extract(1),
+            value.extract(3),
+            value.extract(3),
+        );
         let parallel = scaling_real * self;
         let shuffled = self.swap_iq();
         let cross = scaling_imag * shuffled;
-        unsafe { mem::transmute(_mm256_addsub_pd(mem::transmute(parallel), mem::transmute(cross))) }
+        unsafe {
+            mem::transmute(_mm256_addsub_pd(
+                mem::transmute(parallel),
+                mem::transmute(cross),
+            ))
+        }
     }
 
     #[inline]
     fn div_complex(self, value: f64x4) -> f64x4 {
-        let scaling_imag = f64x4::new(self.extract(0),
-                                      self.extract(0),
-                                      self.extract(2),
-                                      self.extract(2));
-        let scaling_real = f64x4::new(self.extract(1),
-                                      self.extract(1),
-                                      self.extract(3),
-                                      self.extract(3));
+        let scaling_imag = f64x4::new(
+            self.extract(0),
+            self.extract(0),
+            self.extract(2),
+            self.extract(2),
+        );
+        let scaling_real = f64x4::new(
+            self.extract(1),
+            self.extract(1),
+            self.extract(3),
+            self.extract(3),
+        );
         let parallel = scaling_real * value;
         let shuffled = value.swap_iq();
         let cross = scaling_imag * shuffled;
-        let mul: f64x4 = unsafe { mem::transmute(_mm256_addsub_pd(mem::transmute(parallel), mem::transmute(cross))) };
+        let mul: f64x4 = unsafe {
+            mem::transmute(_mm256_addsub_pd(
+                mem::transmute(parallel),
+                mem::transmute(cross),
+            ))
+        };
         let square = shuffled * shuffled;
         let square_shuffled = square.swap_iq();
         let sum = square + square_shuffled;
@@ -289,7 +360,12 @@ impl Simd<f64> for f64x4 {
     #[inline]
     fn complex_abs_squared(self) -> f64x4 {
         let squared = self * self;
-        unsafe { mem::transmute(_mm256_hadd_pd(mem::transmute(squared), mem::transmute(squared))) }
+        unsafe {
+            mem::transmute(_mm256_hadd_pd(
+                mem::transmute(squared),
+                mem::transmute(squared),
+            ))
+        }
     }
 
     #[inline]
@@ -300,12 +376,24 @@ impl Simd<f64> for f64x4 {
 
     #[inline]
     fn complex_abs_squared2(self) -> f64x4 {
-        self.complex_abs_squared()
+        let abs = self.complex_abs_squared();
+        f64x4::new(
+            abs.extract(0),
+            abs.extract(2),
+            abs.extract(1),
+            abs.extract(3),
+        )
     }
 
     #[inline]
     fn complex_abs2(self) -> f64x4 {
-        self.complex_abs()
+        let abs = self.complex_abs();
+        f64x4::new(
+            abs.extract(0),
+            abs.extract(2),
+            abs.extract(1),
+            abs.extract(3),
+        )
     }
 
     #[inline]
@@ -315,11 +403,9 @@ impl Simd<f64> for f64x4 {
 
     #[inline]
     fn store_half_unchecked(self, target: &mut [f64], index: usize) {
-        let mut temp = [0.0; 4];
-        self.store(&mut temp, 0);
         unsafe {
-            *target.get_unchecked_mut(index) = temp[0];
-            *target.get_unchecked_mut(index + 1) = temp[2];
+            *target.get_unchecked_mut(index) = self.extract(0);
+            *target.get_unchecked_mut(index + 1) = self.extract(1);
         }
     }
 
@@ -330,20 +416,22 @@ impl Simd<f64> for f64x4 {
 
     #[inline]
     fn sum_complex(&self) -> Complex<f64> {
-        Complex::<f64>::new(self.extract(0) + self.extract(2),
-                            self.extract(1) + self.extract(3))
+        Complex::<f64>::new(
+            self.extract(0) + self.extract(2),
+            self.extract(1) + self.extract(3),
+        )
     }
-    
+
     #[inline]
     fn max(self, other: Self) -> Self {
         simd::x86::avx::AvxF64x4::max(self, other)
     }
-    
+
     #[inline]
     fn min(self, other: Self) -> Self {
         simd::x86::avx::AvxF64x4::min(self, other)
     }
-    
+
     #[inline]
     fn swap_iq(self) -> Self {
         unsafe { mem::transmute(_mm256_permute_pd(mem::transmute(self), SWAP_IQ_PD)) }
@@ -379,7 +467,7 @@ mod tests {
     use super::*;
 
     #[test]
-    fn shuffle_test() {
+    fn shuffle_test_f32() {
         let vec = f32x8::new(1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0);
         let result = vec.swap_iq();
         assert_eq!(result.extract(0), vec.extract(1));
@@ -391,4 +479,14 @@ mod tests {
         assert_eq!(result.extract(6), vec.extract(7));
         assert_eq!(result.extract(7), vec.extract(6));
     }
-}
\ No newline at end of file
+
+    #[test]
+    fn shuffle_test_f64() {
+        let vec = f64x4::new(1.0, 2.0, 3.0, 4.0);
+        let result = vec.swap_iq();
+        assert_eq!(result.extract(0), vec.extract(1));
+        assert_eq!(result.extract(1), vec.extract(0));
+        assert_eq!(result.extract(2), vec.extract(3));
+        assert_eq!(result.extract(3), vec.extract(2));
+    }
+}
